==> hanja-0.0.2.tar.gz: hanja-0.0.2/hanja.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# File name: hanja.py


#Definitions
def preface(): #Print Preface
	print '한자한글변환기 0.02   제작:마소리스(masoris@gmail.com)'
	print '명령어: 종료(exit), 방식(mode), 정변환, 역변환, 목록(list)'
	print '변환하고자 하는 한자를 입력하시고 엔터를 누르시면 변환이 됩니다.\n'

def command(a): #Analyzing Command and Get Result
	global looping, reverse

	#Commands
	if(a.lower()=='exit' or a =='종료'):
		looping = False
		return
	elif(a == '목록' or a.lower() == 'list'):
		for i in range(0, len(dic0)):
			print dic0[i]+'\t'+dic1[i]		
		return
	elif(a == '정변환'):
		reverse = False
		print '한자를 한글로 변환합니다'
		return
	elif(a == '역변환'):
		reverse = True
		print '한글을 한자로 변환합니다 (시험용)'
		return
	elif(a == '방식' or a.lower() == 'mode' ):
		setmode()
		return

	#Converting
	print '出力'+str(times)+'> '+convert(a)

def convert(a): #Convert Hanja to Hangul
	if(useuni == True):
		for i in range(0, len(dicuni0)):
			a = a.replace(dicuni0[i], dicuni1[i])

	if reverse == True:
		for i in range(0, len(dic0)):
			a = a.replace(dic1[i], dic0[i])		
	else:
		for i in range(0, len(dic0)):
			a = a.replace(dic0[i], dic1[i])		
	return a

def readdic(dicfilename = 'dic1.txt'): #Add Dictionary to dic0, dic1
	global dic0, dic1, message

	dic = file(dicfilename)

	count = 0;
	while(True):
		line = dic.readline()
		if len(line) == 0:
			break
		if line.find('\t') == -1:
			continue

		line = line.replace('\n','')
		splited = line.rsplit('\t')
		if splited[0][0] == '#' or splited[1][0] == '#':
			continue		
		if splited[0][0] == '?' or splited[1][0] == '?':
			continue
		if len(splited) <= 1:
			continue
		if len(splited[0]) == 0 or len(splited[1]) == 0:
			continue
		
		dic0.append(splited[0])
		dic1.append(splited[1])
		count = count + 1

#Check if it correctly read file
#		for i in range(0, len(dic0)):
#		print dic0[i]
#		print dic1[i]
	dic.close()
	if(message):
		print dicfilename+'을 읽어 들임 ( '+str(count)+' 개 )'


def setmode(mode=-1):
	global dic0, dic1, useuni, reverse, message
	dic0 = []
	dic1 = []
	useuni = False

	#Select Mode
	if(mode == -1):
		print '변환하고자 하는 방식을 선택하세요'
		print '1. 다용도 한자 > 한글 변환 시스템 (권장, 기본값)'
		print '2. 유니코드 대표음으로 변환 (MS Word 방식)'
		print '3. 유니코드 정규화 알고리즘 적용 후 한글로 변환 (위키백과)'
		print '4. 두음법칙 비적용 한글로 변환 (문화어)'
		print '5. 한자에 정규화 알고리즘 적용 시키기'
		print '6. 한글 > 한자 변환 (시험용, 한중일 통합 한자 출력)'
		s = raw_input('選擇> ')
		try:
			i = int(s)
		except:
			i = 1
	else:
		i = mode

	#Apply Mode
	if(i == 1):
		readdic('dic4.txt')
		readdic('dic3.txt')
		readdic('dic2.txt')
	elif(i == 2):
		readdic('dic3.txt')
		readdic('dic2.txt')
	elif(i == 3):
		readdic('dic4.txt')
		readdic('dic5.txt')
		readdic('dic1.txt')
		useuni = True
	elif(i == 4):
		readdic('dic1.txt')
		useuni = True
	elif(i == 5):
		readdic('dic0.txt')
	elif(i == 6):
		readdic('dic6.txt')

	if(message):
		print '총 '+str(len(dic0))+' 개 데이터 읽어 들임'


#Prepare Unicode Normalization Algorithm Dictionaries
def loaduni():
	global dicuni0, dicuni1, dic0, dic1
	readdic('dic0.txt')
	dicuni0 = dic0
	dicuni1 = dic1
	dic0 = []
	dic1 = []

#Set Variations
looping = True
inp = '' #inputed command or hanja.
times = 0 #The number of looping times
dic0 = [] #Dictionary0
dic1 = [] #Dictionary1
dicuni0 = [] #Unicode Normalization Algorithm Dictionary0
dicuni1 = [] #Unicode Normalization Algorithm Dictionary1
useuni = False #Use Unicode Normalization Algorithm before Converting
reverse = False #Reverse Converting
message = False #Print Message

	
#Start Programme

#Arguments Start
import sys
loaduni()

arginput = ''
#Is argv1 is text to convert or a filename?
if(len(sys.argv)>=2):
	try:
		f = file(sys.argv[1])
		arginput = f.read()
		f.close		
	except:
		arginput = sys.argv[1]

#Convert argv1 and print result
if(len(sys.argv)==2):
	setmode(1)
	print convert(arginput)

#Convert argv1 by argv2 mode and print result
elif(len(sys.argv)==3):
	setmode(int(sys.argv[2]))	 
	print convert(arginput)

#Convert argv1 by argv2 mode and save result to argv3 file
elif(len(sys.argv)==4):
	setmode(int(sys.argv[2]))
	f = file(sys.argv[3], 'w')
	f.write(convert(arginput))
	f.close

else:
	#Start looping	
	message = True
	preface()
	setmode()
	
	while(looping):
		times = times + 1
		inp = raw_input('\n入力'+str(times)+'> ')
		command(str(inp))
#End Programme

==> hanja-0.0.3.tar.gz: hanja-0.0.3/hanja.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# File name: hanja.py


#Definitions
def preface(): #Print Preface
	print 'Hanja Hangul Converter 0.0.3    by Sung-il KIM (masoris@gmail.com)'
	print 'Commands: exit(종료), mode(방식), reverse(역변환), list(목록)'
	print 'Type hanja to convert and press enter.'

def command(a): #Analyzing Command and Get Result
	global looping, reverse

	#Commands
	if(a.lower()=='exit' or a =='종료'):
		looping = False
		return
	elif(a.lower() == 'list' or a == '목록'):
		for i in range(0, len(dic0)):
			print dic0[i]+'\t'+dic1[i]		
		return
	elif(a.lower() == 'reverse' or a == '정변환' or a == '역변환'):
		if(reverse == True):
			reverse = False
			print 'Convert Hanja to Hangul'
			return
		elif(reverse == False):
			reverse = True
			print 'Convert Hangul to Hanja (Reverse)'
			return
	elif(a.lower() == 'mode' or a == '방식' or a == '모드'):
		setmode()
		print ''
		preface()
		return

	#Converting
	print '出'+str(times)+'> '+convert(a)

def convert(a): #Convert Hanja to Hangul
	if(useuni == True):
		for i in range(0, len(dicuni0)):
			a = a.replace(dicuni0[i], dicuni1[i])

	if reverse == True:
		for i in range(0, len(dic0)):
			a = a.replace(dic1[i], dic0[i])		
	else:
		for i in range(0, len(dic0)):
			a = a.replace(dic0[i], dic1[i])		
	return a

def readdic(dicfilename = 'dic1.txt'): #Add Dictionary to dic0, dic1
	global dic0, dic1, message

	dic = file(dicfilename)

	count = 0;
	while(True):
		line = dic.readline()
		if len(line) == 0:
			break
		if line.find('\t') == -1:
			continue

		line = line.replace('\n','')
		splited = line.rsplit('\t')
		if splited[0][0] == '#' or splited[1][0] == '#':
			continue		
		if splited[0][0] == '?' or splited[1][0] == '?':
			continue
		if len(splited) <= 1:
			continue
		if len(splited[0]) == 0 or len(splited[1]) == 0:
			continue
		
		dic0.append(splited[0])
		dic1.append(splited[1])
		count = count + 1

#Check if it correctly read file
#		for i in range(0, len(dic0)):
#		print dic0[i]
#		print dic1[i]
	dic.close()
	if(message):
		print 'Load '+dicfilename+' file, '+str(count)+' of indexes'


def setmode(mode=-1):
	global dic0, dic1, useuni, reverse, message
	dic0 = []
	dic1 = []
	useuni = False

	#Select Mode
	if(mode == -1):
		print 'Choose mode to convert Hanja to Hangul'
		print '1. Han unification and CJK Compatibility Forms (MS Word)'
		print '2. Han unification only (Wikipedia, default)'
		print '3. Without duuembeobchik (North Korean)'
		print '4. Apply Unicode normalization algorithm'
		print '5. (experiment) Compatible convert with both way (1, 2)'
		print '6. (experiment) Convert Hangul to Hanja'
		s = raw_input('擇> ')
		try:
			i = int(s)
		except:
			i = 2
	else:
		i = mode

	#Apply Mode
	if(i == 1):
		readdic('dic3.txt')
		readdic('dic2.txt')
	elif(i == 2):
		useuni = True
		readdic('dic4.txt')
		readdic('dic5.txt')
		readdic('dic1.txt')
	elif(i == 3):
		useuni = True
		readdic('dic1.txt')
	elif(i == 4):
		useuni = True
	elif(i == 5):
		readdic('dic4.txt')
		readdic('dic3.txt')
		readdic('dic2.txt')
	elif(i == 6):
		readdic('dic6.txt')

	if(message):
		print 'Total '+str(len(dic0))+' of indexes'


#Prepare Unicode Normalization Algorithm Dictionaries
def loaduni():
	global dicuni0, dicuni1, dic0, dic1
	readdic('dic0.txt')
	dicuni0 = dic0
	dicuni1 = dic1
	dic0 = []
	dic1 = []

#Set Variations
looping = True
inp = '' #inputed command or hanja.
times = 0 #The number of looping times
dic0 = [] #Dictionary0
dic1 = [] #Dictionary1
dicuni0 = [] #Unicode Normalization Algorithm Dictionary0
dicuni1 = [] #Unicode Normalization Algorithm Dictionary1
useuni = False #Use Unicode Normalization Algorithm before Converting
reverse = False #Reverse Converting
message = False #Print Message

	
#Start Programme

#Arguments Start
import sys
loaduni()

arginput = ''
#Is argv1 is text to convert or a filename?
if(len(sys.argv)>=2):
	try:
		f = file(sys.argv[1])
		arginput = f.read()
		f.close		
	except:
		arginput = sys.argv[1]

#Convert argv1 and print result
if(len(sys.argv)==2):
	setmode(2)
	print convert(arginput)

#Convert argv1 by argv2 mode and print result
elif(len(sys.argv)==3):
	setmode(int(sys.argv[2]))	 
	print convert(arginput)

#Convert argv1 by argv2 mode and save result to argv3 file
elif(len(sys.argv)==4):
	setmode(int(sys.argv[2]))
	f = file(sys.argv[3], 'w')
	f.write(convert(arginput))
	f.close

#Start looping
else:
	message = True
	preface()
	print ''
	setmode()
	
	while(looping):
		times = times + 1
		inp = raw_input('\n入'+str(times)+'> ')
		command(str(inp))
#End Programme
